@@ -1,14 +1,5 @@
 #' @name print.dust
 #' @export 
-#' @importFrom dplyr group_by_
-#' @importFrom dplyr left_join
-#' @importFrom dplyr mutate_
-#' @importFrom dplyr rename_
-#' @importFrom dplyr select_
-#' @importFrom dplyr ungroup
-#' @importFrom knitr asis_output
-#' @importFrom knitr kable
-#' @importFrom tidyr spread_
 #' @method print dust
 #' 
 #' @title Print A \code{dust} Table
@@ -20,6 +11,13 @@
 #' @details The printing format is drawn from \code{options()$dustpan_output} and may take any of
 #'   the values \code{"console"}, \code{"markdown"}, \code{"html"}, or \code{"latex"}
 #'   
+#'   The markdown, html, and latex output is returned via \code{\link[knitr]{asis_output}},
+#'   which forces the output into the 'asis' environment.  It is intended to work 
+#'   with Rmarkdown, and the tables will be rended regardless of the 
+#'   chunk's \code{results} argument.  Currently, there is no way to to capture
+#'   the code for additional post processing.
+#'   
+#'   
 #' @author Benjamin Nutter
 #' 
 #' @examples 
@@ -31,6 +29,6 @@ print.dust <- function(x, ...)
         "console" = print_dust_console(x, ...),
         "markdown" = print_dust_markdown(x, ...),
         "html" = print_dust_html(x, ...),
-        # "latex" = print_dust_latex(x, ...),
+        "latex" = print_dust_latex(x, ...),
         stop(paste0("'", x$print_method, "' is not an valid print method")))
 }
